@@ -1084,84 +1084,6 @@ class Fsck(object):
         self.conn.execute('DELETE FROM names WHERE refcount=0 AND id=?', (name_id,))
 
 
-class ROFsck(Fsck):
-    '''
-    Check file system database only, and don't correct any errors.
-    '''
-
-    def __init__(self, path):
-
-        db = Connection(path + '.db')
-        db.execute('PRAGMA journal_mode = WAL')
-
-        param = load_params(path)
-        super().__init__(None, None, param, db)
-
-    def check(self):
-
-        self.conn.execute('BEGIN TRANSACTION')
-        try:
-            log.info('Creating temporary indices...')
-            for idx in ('tmp1', 'tmp2', 'tmp3', 'tmp4', 'tmp5'):
-                self.conn.execute('DROP INDEX IF EXISTS %s' % idx)
-            self.conn.execute('CREATE INDEX tmp1 ON blocks(obj_id)')
-            self.conn.execute('CREATE INDEX tmp2 ON inode_blocks(block_id)')
-            self.conn.execute('CREATE INDEX tmp3 ON contents(inode)')
-            self.conn.execute('CREATE INDEX tmp4 ON contents(name_id)')
-            self.conn.execute('CREATE INDEX tmp5 ON ext_attributes(name_id)')
-
-            self.check_lof()
-            self.check_uploads()
-            self.check_names_refcount()
-
-            self.check_contents_name()
-            self.check_contents_inode()
-            self.check_contents_parent_inode()
-
-            self.check_objects_refcount()
-            self.check_objects_size()
-
-            self.check_blocks_obj_id()
-            self.check_blocks_refcount()
-            self.check_blocks_checksum()
-
-            self.check_inode_blocks_block_id()
-            self.check_inode_blocks_inode()
-
-            self.check_inodes_refcount()
-            self.check_inodes_size()
-
-            self.check_ext_attributes_name()
-            self.check_ext_attributes_inode()
-
-            self.check_symlinks_inode()
-
-            self.check_loops()
-            self.check_unix()
-            self.check_foreign_keys()
-
-        finally:
-            log.info('Dropping temporary indices...')
-            self.conn.execute('ROLLBACK')
-
-    def check_blocks_checksum(self):
-        """Check blocks.hash"""
-
-        log.info('Checking blocks (checksums)...')
-
-        for (block_id,) in self.conn.query('SELECT id FROM blocks WHERE hash IS NULL'):
-            self.found_errors = True
-            self.log_error("No cached checksum for block %d!", block_id)
-
-    def check_objects_size(self):
-        """Check objects.size"""
-
-        log.info('Checking objects (sizes)...')
-
-        for (obj_id,) in self.conn.query('SELECT id FROM objects WHERE size IS NULL'):
-            self.found_errors = True
-            self.log_error("Object %d has no size information!", obj_id)
-
 def parse_args(args):
 
     parser = ArgumentParser(
